==> servicecatalog-model-6.8.1-sources.jar: io/fabric8/servicecatalog/api/model/AddKeyTransformFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AddKeyTransformFluent<A extends AddKeyTransformFluent<A>> extends BaseFluent<A>{
  public AddKeyTransformFluent() {
  }
  public AddKeyTransformFluent(AddKeyTransform instance) {
    instance = (instance != null ? instance : new AddKeyTransform());

    if (instance != null) {
      this.withJsonPathExpression(instance.getJsonPathExpression());
      this.withKey(instance.getKey());
      this.withStringValue(instance.getStringValue());
      this.withValue(instance.getValue());
      this.withJsonPathExpression(instance.getJsonPathExpression());
      this.withKey(instance.getKey());
      this.withStringValue(instance.getStringValue());
      this.withValue(instance.getValue());
    }
  }
  private String jsonPathExpression;
  private String key;
  private String stringValue;
  private String value;
  public String getJsonPathExpression() {
    return this.jsonPathExpression;
  }
  public A withJsonPathExpression(String jsonPathExpression) {
    this.jsonPathExpression=jsonPathExpression; return (A) this;
  }
  public boolean hasJsonPathExpression() {
    return this.jsonPathExpression != null;
  }
  public String getKey() {
    return this.key;
  }
  public A withKey(String key) {
    this.key=key; return (A) this;
  }
  public boolean hasKey() {
    return this.key != null;
  }
  public String getStringValue() {
    return this.stringValue;
  }
  public A withStringValue(String stringValue) {
    this.stringValue=stringValue; return (A) this;
  }
  public boolean hasStringValue() {
    return this.stringValue != null;
  }
  public String getValue() {
    return this.value;
  }
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  public boolean hasValue() {
    return this.value != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AddKeyTransformFluent that = (AddKeyTransformFluent) o;
    if (!java.util.Objects.equals(jsonPathExpression, that.jsonPathExpression)) return false;

    if (!java.util.Objects.equals(key, that.key)) return false;

    if (!java.util.Objects.equals(stringValue, that.stringValue)) return false;

    if (!java.util.Objects.equals(value, that.value)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(jsonPathExpression,  key,  stringValue,  value,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (jsonPathExpression != null) { sb.append("jsonPathExpression:"); sb.append(jsonPathExpression + ","); }
    if (key != null) { sb.append("key:"); sb.append(key + ","); }
    if (stringValue != null) { sb.append("stringValue:"); sb.append(stringValue + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> servicecatalog-model-6.9.0-sources.jar: io/fabric8/servicecatalog/api/model/AddKeyTransformFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AddKeyTransformFluent<A extends AddKeyTransformFluent<A>> extends BaseFluent<A>{
  public AddKeyTransformFluent() {
  }
  
  public AddKeyTransformFluent(AddKeyTransform instance) {
    this.copyInstance(instance);
  }
  private String jsonPathExpression;
  private String key;
  private String stringValue;
  private String value;
  
  protected void copyInstance(AddKeyTransform instance) {
    instance = (instance != null ? instance : new AddKeyTransform());
  
    if (instance != null) {
        this.withJsonPathExpression(instance.getJsonPathExpression());
        this.withKey(instance.getKey());
        this.withStringValue(instance.getStringValue());
        this.withValue(instance.getValue());
        this.withJsonPathExpression(instance.getJsonPathExpression());
        this.withKey(instance.getKey());
        this.withStringValue(instance.getStringValue());
        this.withValue(instance.getValue());
      }
  }
  
  public String getJsonPathExpression() {
    return this.jsonPathExpression;
  }
  
  public A withJsonPathExpression(String jsonPathExpression) {
    this.jsonPathExpression=jsonPathExpression; return (A) this;
  }
  
  public boolean hasJsonPathExpression() {
    return this.jsonPathExpression != null;
  }
  
  public String getKey() {
    return this.key;
  }
  
  public A withKey(String key) {
    this.key=key; return (A) this;
  }
  
  public boolean hasKey() {
    return this.key != null;
  }
  
  public String getStringValue() {
    return this.stringValue;
  }
  
  public A withStringValue(String stringValue) {
    this.stringValue=stringValue; return (A) this;
  }
  
  public boolean hasStringValue() {
    return this.stringValue != null;
  }
  
  public String getValue() {
    return this.value;
  }
  
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  
  public boolean hasValue() {
    return this.value != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AddKeyTransformFluent that = (AddKeyTransformFluent) o;
    if (!java.util.Objects.equals(jsonPathExpression, that.jsonPathExpression)) return false;
  
    if (!java.util.Objects.equals(key, that.key)) return false;
  
    if (!java.util.Objects.equals(stringValue, that.stringValue)) return false;
  
    if (!java.util.Objects.equals(value, that.value)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(jsonPathExpression,  key,  stringValue,  value,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (jsonPathExpression != null) { sb.append("jsonPathExpression:"); sb.append(jsonPathExpression + ","); }
    if (key != null) { sb.append("key:"); sb.append(key + ","); }
    if (stringValue != null) { sb.append("stringValue:"); sb.append(stringValue + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  

}
